#
# spec file for package cpp-httplib
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0.12
%define libver 0_12
Name:           cpp-httplib
Version:        0.12.5
Release:        bp156.2.3.1
Summary:        A C++11 HTTP/HTTPS library
License:        MIT
URL:            https://github.com/yhirose/cpp-httplib
Source0:        https://codeload.github.com/yhirose/cpp-httplib/tar.gz/refs/tags/v%{version}#/%{name}-%{version}.tar.gz
# CVE-2025-0825 [bsc#1236790], fails to filter CRLF characters (quot;rnquot;) when those are prefixed with a null byte
Patch0:         cpp-httplib-CVE-2025-0825.patch
BuildRequires:  gcc-c++
BuildRequires:  meson >= 0.47.0
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(libbrotlidec)
BuildRequires:  pkgconfig(libbrotlienc)
BuildRequires:  pkgconfig(openssl) >= 1.1.1

%package -n lib%{name}%{libver}
Summary:        A C++11 HTTP/HTTPS library

%package devel
Summary:        A C++11 HTTP/HTTPS library
Requires:       lib%{name}%{libver} = %{version}
Conflicts:      cpp-httplib-headers-devel

%description
This is a multi-threaded HTTP library with blocking I/O. There is no
support for non-blocking mode.

%description -n lib%{name}%{libver}
This is a multi-threaded HTTP library with blocking I/O. There is no
support for non-blocking mode.

%description devel
This is a multi-threaded HTTP library with blocking I/O. There is no
support for non-blocking mode.

It features built-in mappings, static file server, pre-routing and
post-routing handlers, and support for binding sockets to multiple
interfaces and any available port.

%prep
%autosetup -p1
chmod -x example/uploader.sh

%build
%meson -Dcpp-httplib_compile=true -Dcpp-httplib_test=true \
       --buildtype=release
%meson_build

%install
%meson_install

%check
# OBS and chroot build environments does not provide internet
# connectivity, skip online tests to avoid failures
export GTEST_FILTER='-*.*_Online'
%meson_test

%post   -n lib%{name}%{libver} -p /sbin/ldconfig
%postun -n lib%{name}%{libver} -p /sbin/ldconfig

%files -n lib%{name}%{libver}
%{_libdir}/lib%{name}.so.%{sover}
%{_libdir}/lib%{name}.so.%{version}
%license LICENSE

%files devel
%{_libdir}/lib%{name}.so
%{_includedir}/httplib.h
%{_libdir}/pkgconfig/%{name}.pc
%doc README.md example

%changelog
* Thu Feb  6 2025 pgajdos@suse.com
- security update
- added patches
  fix CVE-2025-0825 [bsc#1236790], fails to filter CRLF characters when those are prefixed with a null byte
  + cpp-httplib-CVE-2025-0825.patch
* Wed May 31 2023 Alexey Svistunov <svalx@svalx.net>
- Update to version 0.12.5:
  * Add HTTPLIB_INSTALL CMake option (#1575)
  * Fix more CRLF injection problems
  * Don't loading system certs from Keychain on iOS (#1546)
  * Initialize sockaddr_un to fix valgrind uninitialised byte message. (#1547, #1547)
  * Using set_content_provider with length of 0 makes it infinitely loop (#1545)
  * How to check if server is running successfully in another thread? (#1548)
  * Fix leaked handle in create_socket (#1554)
  * Fix "Location" header url corrupted by percent-unescaping in redirect… (#1459)
  * Trailing headers not handled (#1486)
  * SSL access through a proxy causes SIGSEGV (#1533)
  * System certs support on macOS (#1474)
  * Add Request::get_file_values method (#1495)
  * Fix: assert socket_requests_are_from_thread_ std::this_thread::get_id() (#1498)
  * Fix: multipart Content-Type headers with both boundary and charset parameters (#1516)
* Thu Feb 16 2023 Alexey Svistunov <svalx@svalx.net>
- Move examples to devel subpackage
- Drop headers-only flavor and remove aliases for pkg-config files
  (gh#yhirose/cpp-httplib#1491)
* Thu Feb  9 2023 Alexey Svistunov <svalx@svalx.net>
- Update to version 0.12.0:
  * Removed is_writable() from DataSink (Resolve #1478, too) (#1483)
  * Fix #1479
  * Removed incorrect comment
  * Support CTest (#1468)
  * Issue 52666: cpp-httplib:server_fuzzer: Timeout in server_fuzzer
  * add to_human_string (#1467)
* Wed Feb  8 2023 Alexey Svistunov <svalx@svalx.net>
- Switch to meson tests
- Add examples to headers package
* Mon Feb  6 2023 Alexey Svistunov <svalx@svalx.net>
- For an explicit choice when buildtime dependencies resolving
  added an unique pkgconfig files aliases for both shipped library
  flavors: cpp-httplib-headers.pc and cpp-httplib-shared.pc
- Enable tests performing for compiled flavor
* Tue Jan 24 2023 Alexey Svistunov <svalx@svalx.net>
- Migrate from obscpio to classical tar.gz sources archive for properly
  debugsource package building
* Tue Jan 17 2023 Alexey Svistunov <svalx@svalx.net>
- Update to version 0.11.4:
  * add support for requests with both MultipartFormDataItems and Content Providers (#1454)
  * Add EINTR and EAGAIN judge for accept (#1438)
  * Updated unit test
  * std::condition_variable::notify_one/all() should be called after unlocking mutex (#1448)
  * Support LOCAL_ADDR and LOCAL_PORT header in client Request (#1450)
  * Fix #1442
  * Removed code for upsupported OpenSSL
- Combined multibuild cpp-httplib and cpp-httplib-headers packages
- Remove unneeded BuildRequires for cpp-httplib-headers
* Mon Jan 16 2023 Alexey Svistunov <svalx@svalx.net>
- Move LICENSE file to the library package
- Drop cmake BuildRequires and linker additional "-s" flag
* Mon Jan  2 2023 Jan Engelhardt <jengelh@inai.de>
- Redo description so it does not rely on monospace formatting.
* Mon Dec 26 2022 Alexey Svistunov <svalx@svalx.net>
- Move README.md to devel subpackage
* Mon Dec 26 2022 svalx@svalx.net
- Update to version 0.11.3:
  * Fix #1426
  * Fix #1437
  * Windows CMake directory install fix (#1434)
* Fri Dec 23 2022 Alexey Svistunov <svalx@svalx.net>
- Initial release
